@@ -6,6 +6,7 @@
 #define SLIDESHOWSCREENSAVER_H
 
 #include <QWidget>
+#include <QMap>
 
 class SlideshowScreenSaver : public QWidget
 {
@@ -22,8 +23,11 @@ protected:
 
 private:
     void showDefaultBlack(QPaintEvent *event);
-    bool updateCurrentImageIndex();
-    bool loadSlideshowImages();
+    void randomImageIndex();
+    void loadSlideshowImages();
+    void init();
+    void nextValidPath();
+    void filterInvalidFile(const QString &path);
 
 private:
     QScopedPointer<QPixmap> m_pixmap;
@@ -33,10 +37,10 @@ private:
     bool m_shuffle { false };   // 随机轮播
     int m_intervalTime { 0 };   // 轮播间隔
     int m_currentIndex { 0 };
-
     QStringList m_imagefiles;
-
     bool m_subWindow { false };
+    QMap<int, QString> m_playOrder;
+    QString m_lastImage;
 };
 
 #endif   // SLIDESHOWSCREENSAVER_H
