@@ -1,33 +1,19 @@
-/*
- * Copyright (C) 2017 ~ 2019 Deepin Technology Co., Ltd.
- *
- * Author:     zccrs <zccrs@live.com>
- *
- * Maintainer: zccrs <zhangjide@deepin.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2017 ~ 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #ifndef DBUSSCREENSAVER_H
 #define DBUSSCREENSAVER_H
 
+#include <com_deepin_sessionmanager.h>
+
 #include <QObject>
-#include <QProcess>
 #include <QDir>
 #include <QTimer>
 #include <QSettings>
 #include <QDBusMessage>
 #include <QScreen>
+#include <QAtomicInteger>
 
 class ScreenSaverWindow;
 class X11EventFilter;
@@ -68,6 +54,9 @@ public:
     void setLockScreenAtAwake(bool lockScreenAtAwake);
     void setLockScreenDelay(int lockScreenDelay);
 
+    bool StartCustomConfig(const QString &name);
+    QStringList ConfigurableItems();
+    bool IsConfigurable(const QString &name);
 signals:
     void allScreenSaverChanged(QStringList allScreenSaver);
     void batteryScreenSaverTimeoutChanged(int batteryScreenSaverTimeout);
@@ -85,6 +74,10 @@ private:
     void onScreenAdded(QScreen *s);
     void cleanWindow(ScreenSaverWindow *w);
 
+    void XGrabKeyBoard();
+    void XUnGrabKeyBoard();
+    void onLockedChanged(const bool locked);
+
     QList<QDir> m_resourceDirList;
     QStringList m_resourceList;
 
@@ -100,6 +93,9 @@ private:
     QTimer m_autoQuitTimer;
     QSettings m_settings;
     QScopedPointer<X11EventFilter> x11event;
+
+    com::deepin::SessionManager *m_sessionManagerInter = nullptr;
+    QAtomicInteger<bool> m_grabKeyboard = false;
 };
 
 #endif // DBUSSCREENSAVER_H
