@@ -1,29 +1,17 @@
-/*
- * Copyright (C) 2017 ~ 2019 Deepin Technology Co., Ltd.
- *
- * Author:     zccrs <zccrs@live.com>
- *
- * Maintainer: zccrs <zhangjide@deepin.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
-#include <QGuiApplication>
+// SPDX-FileCopyrightText: 2017 ~ 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
+#include <DApplication>
+
 #include <QCommandLineParser>
 #include <QCommandLineOption>
 
 #include "screensaver_adaptor.h"
 #include "dbusscreensaver.h"
+#include "customconfig.h"
+
+DWIDGET_USE_NAMESPACE
 
 #define APPLICATION_XSTRING(s) APPLICATION_STRING(s)
 #define APPLICATION_STRING(s) #s
@@ -48,32 +36,54 @@ int main(int argc, char *argv[])
 {
     auto envType = qEnvironmentVariable("XDG_SESSION_TYPE");
     if (envType.contains("wayland")) {
+        qInfo() << QDateTime::currentDateTime().toString() << "notes:change wayland to xcb for QT_QPA_PLATFORM.";
         qputenv("QT_QPA_PLATFORM", "xcb");
     }
 
-    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-    QGuiApplication app(argc, argv);
+    DApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+    DApplication app(argc, argv);
 
     app.setOrganizationName("deepin");
     app.setApplicationName("deepin-screensaver");
     app.setApplicationVersion(buildVersion(QMAKE_VERSION));
 
     bool doStart = true;
+    bool isCustomConfig = false;
+    QString configName;
 
     QCommandLineParser parser;
-
     if (argc > 1) {
-        QCommandLineOption option_dbus({"d", "dbus"}, "Register DBus service.");
-        QCommandLineOption option_start({"s", "start"}, "Start screen saver.");
+        QCommandLineOption optionDbus({"d", "dbus"}, "Register DBus service.");
+        QCommandLineOption optionStart({"s", "start"}, "Start screen saver.");
+        QCommandLineOption optionConfig({"c", "config"}, "Start config dialog of screen saver.", "screensaer-name", "");
 
-        parser.addOption(option_dbus);
-        parser.addOption(option_start);
+        parser.addOption(optionDbus);
+        parser.addOption(optionStart);
+        parser.addOption(optionConfig);
         parser.addPositionalArgument("screensaer-name", "Use the screensaver application.", "[name]");
         parser.addHelpOption();
         parser.addVersionOption();
 
         parser.process(app);
-        doStart = !parser.isSet(option_dbus);
+        doStart = !parser.isSet(optionDbus);
+
+        isCustomConfig = parser.isSet(optionConfig);
+        configName = parser.value(optionConfig);
+    }
+
+    // custom config dialog
+    if (isCustomConfig) {
+        if (configName.isEmpty()) {
+            parser.showHelp(1);
+            return 1;
+        } else {
+            app.setQuitOnLastWindowClosed(true);
+            CustomConfig conf;
+            if (conf.startCustomConfig(configName))
+                return app.exec();
+            else
+                return 0;
+        }
     }
 
     // 注册DBus服务
@@ -85,19 +95,21 @@ int main(int argc, char *argv[])
             return -1;
     }
 
+    const QString serviceName = "com.deepin.ScreenSaver";
+    const QString objDbusPath = "/com/deepin/ScreenSaver";
     // add our D-Bus interface and connect to D-Bus
-    if (!QDBusConnection::sessionBus().registerService("com.deepin.ScreenSaver")) {
-        qWarning("Cannot register the \"com.deepin.ScreenSaver\" service.\n");
+    if (!QDBusConnection::sessionBus().registerService(serviceName)) {
+        qWarning() << QString("Cannot register the \"%1\" service.\n").arg(serviceName);
 
         if (!doStart)
             return -1;
     }
 
     auto server = new DBusScreenSaver();
-    Q_UNUSED(new ScreenSaverAdaptor(server))
+    Q_UNUSED(new ScreenSaverAdaptor(qobject_cast<DBusScreenSaver*>(server)))
 
-    if (!QDBusConnection::sessionBus().registerObject("/com/deepin/ScreenSaver", server)) {
-        qWarning("Cannot register to the D-Bus object: \"/com/deepin/ScreenSaver\"\n");
+    if (!QDBusConnection::sessionBus().registerObject(objDbusPath, server)) {
+        qWarning() << QString("Cannot register to the D-Bus object: \"%1\"\n").arg(objDbusPath);
 
         if (!doStart)
             return -1;
